@@ -18,6 +18,10 @@
 #' field in the post objects, and not the \code{created_time}. As a result, this function
 #' might return old posts that have been updated recently. 
 #'
+#' \code{comments_count} refers to the total of comments, including nested comments (replies).
+#' It might be different from the total number of comments available through the API if
+#' some comments have been deleted.
+#'
 #' @author
 #' Pablo Barbera \email{pablo.barbera@@nyu.edu}
 #' @seealso \code{\link{getUsers}}, \code{\link{getPost}}, \code{\link{fbOAuth}}
@@ -47,6 +51,8 @@
 #'
 #' @param verbose If \code{TRUE}, will report a number of the posts retrieved.
 #'
+#' @param api API version. e.g. "v2.8". \code{NULL} is the default.
+#' 
 #' @examples \dontrun{
 #' ## See examples for fbOAuth to know how token was created.
 #' ## Getting information about Facebook's Facebook Page
@@ -62,7 +68,8 @@
 #'
 
 
-getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, reactions=FALSE, verbose=TRUE){
+getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, reactions=FALSE, 
+	verbose=TRUE, api=NULL){
 
 	url <- paste0('https://graph.facebook.com/', page,
 		'/posts?fields=from,message,created_time,type,link,story,comments.summary(true)',
@@ -85,7 +92,7 @@ getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, react
 		url <- paste0(url, "&limit=25")
 	}
 	# making query
-	content <- callAPI(url=url, token=token)
+	content <- callAPI(url=url, token=token, api=api)
 	l <- length(content$data); if (verbose) cat(l, "posts ")
 	
 	## retrying 3 times if error was found
@@ -98,7 +105,7 @@ getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, react
 		if (error==3){ stop(content$error_msg) }
 	}
 	if (length(content$data)==0){ 
-		message("No public posts were found")
+		message("No public posts were found : ", page)
 		return(data.frame())
 	}
 	df <- pageDataToDF(content$data)
@@ -123,7 +130,7 @@ getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, react
 			# waiting one second before making next API call...
 			Sys.sleep(0.5)
 			url <- content$paging$`next`
-			content <- callAPI(url=url, token=token)
+			content <- callAPI(url=url, token=token, api=api)
 			l <- l + length(content$data)
 			if (length(content$data)>0){ if (verbose) cat(l, "posts ") }
 
@@ -133,7 +140,7 @@ getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, react
 				cat("Error!\n")
 				Sys.sleep(0.5)
 				error <- error + 1
-				content <- callAPI(url=url, token=token)		
+				content <- callAPI(url=url, token=token, api=api)
 				if (error==3){ stop(content$error_msg) }
 			}
 			new.df <- pageDataToDF(content$data)
@@ -159,7 +166,7 @@ getPage <- function(page, token, n=25, since=NULL, until=NULL, feed=FALSE, react
 
 	# adding reactions data
 	if (reactions==TRUE){
-		re = getReactions(df$id, token=token, verbose=FALSE)
+		re = getReactions(df$id, token=token, verbose=FALSE, api=api)
 		df <- merge(df, re, all.x=TRUE)
 		# sorting
 		df <- df[order(df$created_time),]
